@@ -96,17 +96,17 @@ Utilize ‘-h’ ou ‘--horizontal’ para exibir os botões na posição horiz
     <message>
         <location filename="../main.cpp" line="58"/>
         <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
-        <translation>Como alternativa, você pode definir a opção &apos;layout=horizontal&apos; ou &apos;layout=vertical&apos; no arquivo de configurações ~/.config/MX-Linux/exit-options.conf</translation>
+        <translation>Como alternativa, você pode definir a opção ‘layout=horizontal’ ou ‘layout=vertical’ no arquivo de configurações ~/.config/MX-Linux/exit-options.conf</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="62"/>
         <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
-        <translation>Você pode definir os ícones personalizados adicionando o parâmetro &apos;IconName=/path/iconame.ext&apos; no arquivo de configurações &apos;options.conf&apos;. Os nomes dos ícones que você pode remapear são: %1</translation>
+        <translation>Você pode definir os ícones personalizados adicionando o parâmetro ‘IconName=/path/iconame.ext’ no arquivo de configurações ‘options.conf’. Os nomes dos ícones que você pode remapear são: %1</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="66"/>
         <source>Other options that can be set in the exit-options.conf file: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>As outras opções que podem ser definidas no arquivo de configurações ‘exit-options.conf’ são: %1</translation>
     </message>
 </context>
 </TS>
